The load balancer occupies a neutron network port and has an IP address assigned from a subnet.

IP address: If an IP address is provided it must be a well-formed IPv4 or IPv6 address. The system will attempt to assign the provided IP address to the load balancer. If an IP address is not provided then one will be allocated for you.

Subnet: The network on which to allocate the load balancer's IP address.